@@ -12,9 +12,10 @@ from .._jsii import *
 
 from .. import (
     Component as _Component_2b0ad27f,
+    GitHubProject as _GitHubProject_8c232467,
+    GitHubProjectOptions as _GitHubProjectOptions_29a16188,
     LoggerOptions as _LoggerOptions_eb0f6309,
     Project as _Project_57d89203,
-    ProjectOptions as _ProjectOptions_0d5b93c6,
     ProjectType as _ProjectType_fd80c725,
     SampleReadmeProps as _SampleReadmeProps_3518b03b,
 )
@@ -25,11 +26,12 @@ from ..github import (
     GitHubOptions as _GitHubOptions_21553699,
     StaleOptions as _StaleOptions_929db764,
 )
+from ..json import ProjenrcOptions as _ProjenrcOptions_985561af
 from ..tasks import Task as _Task_fb843092
 
 
 class JavaProject(
-    _Project_57d89203,
+    _GitHubProject_8c232467,
     metaclass=jsii.JSIIMeta,
     jsii_type="projen.java.JavaProject",
 ):
@@ -53,7 +55,6 @@ class JavaProject(
         sample: typing.Optional[builtins.bool] = None,
         sample_java_package: typing.Optional[builtins.str] = None,
         test_deps: typing.Optional[typing.Sequence[builtins.str]] = None,
-        name: builtins.str,
         auto_approve_options: typing.Optional[_AutoApproveOptions_dac86cbe] = None,
         auto_merge_options: typing.Optional[_AutoMergeOptions_d112cd3c] = None,
         clobber: typing.Optional[builtins.bool] = None,
@@ -61,10 +62,7 @@ class JavaProject(
         github: typing.Optional[builtins.bool] = None,
         github_options: typing.Optional[_GitHubOptions_21553699] = None,
         gitpod: typing.Optional[builtins.bool] = None,
-        logging: typing.Optional[_LoggerOptions_eb0f6309] = None,
         mergify: typing.Optional[builtins.bool] = None,
-        outdir: typing.Optional[builtins.str] = None,
-        parent: typing.Optional[_Project_57d89203] = None,
         project_type: typing.Optional[_ProjectType_fd80c725] = None,
         readme: typing.Optional[_SampleReadmeProps_3518b03b] = None,
         stale: typing.Optional[builtins.bool] = None,
@@ -76,6 +74,12 @@ class JavaProject(
         description: typing.Optional[builtins.str] = None,
         packaging: typing.Optional[builtins.str] = None,
         url: typing.Optional[builtins.str] = None,
+        name: builtins.str,
+        logging: typing.Optional[_LoggerOptions_eb0f6309] = None,
+        outdir: typing.Optional[builtins.str] = None,
+        parent: typing.Optional[_Project_57d89203] = None,
+        projenrc_json: typing.Optional[builtins.bool] = None,
+        projenrc_json_options: typing.Optional[_ProjenrcOptions_985561af] = None,
     ) -> None:
         '''
         :param compile_options: (experimental) Compile options. Default: - defaults
@@ -89,7 +93,6 @@ class JavaProject(
         :param sample: (experimental) Include sample code and test if the relevant directories don't exist.
         :param sample_java_package: (experimental) The java package to use for the code sample. Default: "org.acme"
         :param test_deps: (experimental) List of test dependencies for this project. Dependencies use the format: ``<groupId>/<artifactId>@<semver>`` Additional dependencies can be added via ``project.addTestDependency()``. Default: []
-        :param name: (experimental) This is the name of your project. Default: $BASEDIR
         :param auto_approve_options: (experimental) Enable and configure the 'auto approve' workflow. Default: - auto approve is disabled
         :param auto_merge_options: (experimental) Configure options for automatic merging on GitHub. Has no effect if ``github.mergify`` is set to false. Default: - see defaults in ``AutoMergeOptions``
         :param clobber: (experimental) Add a ``clobber`` task which resets the repo to origin. Default: true
@@ -97,11 +100,8 @@ class JavaProject(
         :param github: (experimental) Enable GitHub integration. Enabled by default for root projects. Disabled for non-root projects. Default: true
         :param github_options: (experimental) Options for GitHub integration. Default: - see GitHubOptions
         :param gitpod: (experimental) Add a Gitpod development environment. Default: false
-        :param logging: (experimental) Configure logging options such as verbosity. Default: {}
         :param mergify: (deprecated) Whether mergify should be enabled on this repository or not. Default: true
-        :param outdir: (experimental) The root directory of the project. Relative to this directory, all files are synthesized. If this project has a parent, this directory is relative to the parent directory and it cannot be the same as the parent or any of it's other sub-projects. Default: "."
-        :param parent: (experimental) The parent project, if this project is part of a bigger project.
-        :param project_type: (experimental) Which type of project this is (library/app). Default: ProjectType.UNKNOWN
+        :param project_type: (deprecated) Which type of project this is (library/app). Default: ProjectType.UNKNOWN
         :param readme: (experimental) The README setup. Default: - { filename: 'README.md', contents: '# replace this' }
         :param stale: (experimental) Auto-close of stale issues and pull request. See ``staleOptions`` for options. Default: true
         :param stale_options: (experimental) Auto-close stale issues and pull requests. To disable set ``stale`` to ``false``. Default: - see defaults in ``StaleOptions``
@@ -112,6 +112,12 @@ class JavaProject(
         :param description: (experimental) Description of a project is always good. Although this should not replace formal documentation, a quick comment to any readers of the POM is always helpful. Default: undefined
         :param packaging: (experimental) Project packaging format. Default: "jar"
         :param url: (experimental) The URL, like the name, is not required. This is a nice gesture for projects users, however, so that they know where the project lives. Default: undefined
+        :param name: (experimental) This is the name of your project. Default: $BASEDIR
+        :param logging: (experimental) Configure logging options such as verbosity. Default: {}
+        :param outdir: (experimental) The root directory of the project. Relative to this directory, all files are synthesized. If this project has a parent, this directory is relative to the parent directory and it cannot be the same as the parent or any of it's other sub-projects. Default: "."
+        :param parent: (experimental) The parent project, if this project is part of a bigger project.
+        :param projenrc_json: (experimental) Generate (once) .projenrc.json (in JSON). Set to ``false`` in order to disable .projenrc.json generation. Default: false
+        :param projenrc_json_options: (experimental) Options for .projenrc.json. Default: - default options
 
         :stability: experimental
         '''
@@ -127,7 +133,6 @@ class JavaProject(
             sample=sample,
             sample_java_package=sample_java_package,
             test_deps=test_deps,
-            name=name,
             auto_approve_options=auto_approve_options,
             auto_merge_options=auto_merge_options,
             clobber=clobber,
@@ -135,10 +140,7 @@ class JavaProject(
             github=github,
             github_options=github_options,
             gitpod=gitpod,
-            logging=logging,
             mergify=mergify,
-            outdir=outdir,
-            parent=parent,
             project_type=project_type,
             readme=readme,
             stale=stale,
@@ -150,9 +152,15 @@ class JavaProject(
             description=description,
             packaging=packaging,
             url=url,
+            name=name,
+            logging=logging,
+            outdir=outdir,
+            parent=parent,
+            projenrc_json=projenrc_json,
+            projenrc_json_options=projenrc_json_options,
         )
 
-        jsii.create(JavaProject, self, [options])
+        jsii.create(self.__class__, self, [options])
 
     @jsii.member(jsii_name="addDependency")
     def add_dependency(self, spec: builtins.str) -> None:
@@ -287,7 +295,7 @@ class Junit(
             pom=pom, sample_java_package=sample_java_package, version=version
         )
 
-        jsii.create(Junit, self, [project, options])
+        jsii.create(self.__class__, self, [project, options])
 
 
 @jsii.data_type(
@@ -395,7 +403,7 @@ class MavenCompile(
         '''
         options = MavenCompileOptions(source=source, target=target)
 
-        jsii.create(MavenCompile, self, [project, pom, options])
+        jsii.create(self.__class__, self, [project, pom, options])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="compileTask")
@@ -502,7 +510,7 @@ class MavenPackaging(
             sources=sources,
         )
 
-        jsii.create(MavenPackaging, self, [project, pom, options])
+        jsii.create(self.__class__, self, [project, pom, options])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="task")
@@ -627,7 +635,7 @@ class MavenSample(
         '''
         options = MavenSampleOptions(package=package)
 
-        jsii.create(MavenSample, self, [project, options])
+        jsii.create(self.__class__, self, [project, options])
 
 
 @jsii.data_type(
@@ -847,7 +855,7 @@ class Pom(_Component_2b0ad27f, metaclass=jsii.JSIIMeta, jsii_type="projen.java.P
             url=url,
         )
 
-        jsii.create(Pom, self, [project, options])
+        jsii.create(self.__class__, self, [project, options])
 
     @jsii.member(jsii_name="addDependency")
     def add_dependency(self, spec: builtins.str) -> None:
@@ -1187,7 +1195,7 @@ class Projenrc(
             class_name=class_name, projen_version=projen_version, test_scope=test_scope
         )
 
-        jsii.create(Projenrc, self, [project, pom, options])
+        jsii.create(self.__class__, self, [project, pom, options])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="className")
@@ -1287,9 +1295,14 @@ class ProjenrcOptions:
 
 @jsii.data_type(
     jsii_type="projen.java.JavaProjectOptions",
-    jsii_struct_bases=[_ProjectOptions_0d5b93c6, PomOptions],
+    jsii_struct_bases=[_GitHubProjectOptions_29a16188, PomOptions],
     name_mapping={
         "name": "name",
+        "logging": "logging",
+        "outdir": "outdir",
+        "parent": "parent",
+        "projenrc_json": "projenrcJson",
+        "projenrc_json_options": "projenrcJsonOptions",
         "auto_approve_options": "autoApproveOptions",
         "auto_merge_options": "autoMergeOptions",
         "clobber": "clobber",
@@ -1297,10 +1310,7 @@ class ProjenrcOptions:
         "github": "github",
         "github_options": "githubOptions",
         "gitpod": "gitpod",
-        "logging": "logging",
         "mergify": "mergify",
-        "outdir": "outdir",
-        "parent": "parent",
         "project_type": "projectType",
         "readme": "readme",
         "stale": "stale",
@@ -1325,11 +1335,16 @@ class ProjenrcOptions:
         "test_deps": "testDeps",
     },
 )
-class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
+class JavaProjectOptions(_GitHubProjectOptions_29a16188, PomOptions):
     def __init__(
         self,
         *,
         name: builtins.str,
+        logging: typing.Optional[_LoggerOptions_eb0f6309] = None,
+        outdir: typing.Optional[builtins.str] = None,
+        parent: typing.Optional[_Project_57d89203] = None,
+        projenrc_json: typing.Optional[builtins.bool] = None,
+        projenrc_json_options: typing.Optional[_ProjenrcOptions_985561af] = None,
         auto_approve_options: typing.Optional[_AutoApproveOptions_dac86cbe] = None,
         auto_merge_options: typing.Optional[_AutoMergeOptions_d112cd3c] = None,
         clobber: typing.Optional[builtins.bool] = None,
@@ -1337,10 +1352,7 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
         github: typing.Optional[builtins.bool] = None,
         github_options: typing.Optional[_GitHubOptions_21553699] = None,
         gitpod: typing.Optional[builtins.bool] = None,
-        logging: typing.Optional[_LoggerOptions_eb0f6309] = None,
         mergify: typing.Optional[builtins.bool] = None,
-        outdir: typing.Optional[builtins.str] = None,
-        parent: typing.Optional[_Project_57d89203] = None,
         project_type: typing.Optional[_ProjectType_fd80c725] = None,
         readme: typing.Optional[_SampleReadmeProps_3518b03b] = None,
         stale: typing.Optional[builtins.bool] = None,
@@ -1367,6 +1379,11 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
         '''(experimental) Options for ``JavaProject``.
 
         :param name: (experimental) This is the name of your project. Default: $BASEDIR
+        :param logging: (experimental) Configure logging options such as verbosity. Default: {}
+        :param outdir: (experimental) The root directory of the project. Relative to this directory, all files are synthesized. If this project has a parent, this directory is relative to the parent directory and it cannot be the same as the parent or any of it's other sub-projects. Default: "."
+        :param parent: (experimental) The parent project, if this project is part of a bigger project.
+        :param projenrc_json: (experimental) Generate (once) .projenrc.json (in JSON). Set to ``false`` in order to disable .projenrc.json generation. Default: false
+        :param projenrc_json_options: (experimental) Options for .projenrc.json. Default: - default options
         :param auto_approve_options: (experimental) Enable and configure the 'auto approve' workflow. Default: - auto approve is disabled
         :param auto_merge_options: (experimental) Configure options for automatic merging on GitHub. Has no effect if ``github.mergify`` is set to false. Default: - see defaults in ``AutoMergeOptions``
         :param clobber: (experimental) Add a ``clobber`` task which resets the repo to origin. Default: true
@@ -1374,11 +1391,8 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
         :param github: (experimental) Enable GitHub integration. Enabled by default for root projects. Disabled for non-root projects. Default: true
         :param github_options: (experimental) Options for GitHub integration. Default: - see GitHubOptions
         :param gitpod: (experimental) Add a Gitpod development environment. Default: false
-        :param logging: (experimental) Configure logging options such as verbosity. Default: {}
         :param mergify: (deprecated) Whether mergify should be enabled on this repository or not. Default: true
-        :param outdir: (experimental) The root directory of the project. Relative to this directory, all files are synthesized. If this project has a parent, this directory is relative to the parent directory and it cannot be the same as the parent or any of it's other sub-projects. Default: "."
-        :param parent: (experimental) The parent project, if this project is part of a bigger project.
-        :param project_type: (experimental) Which type of project this is (library/app). Default: ProjectType.UNKNOWN
+        :param project_type: (deprecated) Which type of project this is (library/app). Default: ProjectType.UNKNOWN
         :param readme: (experimental) The README setup. Default: - { filename: 'README.md', contents: '# replace this' }
         :param stale: (experimental) Auto-close of stale issues and pull request. See ``staleOptions`` for options. Default: true
         :param stale_options: (experimental) Auto-close stale issues and pull requests. To disable set ``stale`` to ``false``. Default: - see defaults in ``StaleOptions``
@@ -1403,14 +1417,16 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
 
         :stability: experimental
         '''
+        if isinstance(logging, dict):
+            logging = _LoggerOptions_eb0f6309(**logging)
+        if isinstance(projenrc_json_options, dict):
+            projenrc_json_options = _ProjenrcOptions_985561af(**projenrc_json_options)
         if isinstance(auto_approve_options, dict):
             auto_approve_options = _AutoApproveOptions_dac86cbe(**auto_approve_options)
         if isinstance(auto_merge_options, dict):
             auto_merge_options = _AutoMergeOptions_d112cd3c(**auto_merge_options)
         if isinstance(github_options, dict):
             github_options = _GitHubOptions_21553699(**github_options)
-        if isinstance(logging, dict):
-            logging = _LoggerOptions_eb0f6309(**logging)
         if isinstance(readme, dict):
             readme = _SampleReadmeProps_3518b03b(**readme)
         if isinstance(stale_options, dict):
@@ -1429,6 +1445,16 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
             "group_id": group_id,
             "version": version,
         }
+        if logging is not None:
+            self._values["logging"] = logging
+        if outdir is not None:
+            self._values["outdir"] = outdir
+        if parent is not None:
+            self._values["parent"] = parent
+        if projenrc_json is not None:
+            self._values["projenrc_json"] = projenrc_json
+        if projenrc_json_options is not None:
+            self._values["projenrc_json_options"] = projenrc_json_options
         if auto_approve_options is not None:
             self._values["auto_approve_options"] = auto_approve_options
         if auto_merge_options is not None:
@@ -1443,14 +1469,8 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
             self._values["github_options"] = github_options
         if gitpod is not None:
             self._values["gitpod"] = gitpod
-        if logging is not None:
-            self._values["logging"] = logging
         if mergify is not None:
             self._values["mergify"] = mergify
-        if outdir is not None:
-            self._values["outdir"] = outdir
-        if parent is not None:
-            self._values["parent"] = parent
         if project_type is not None:
             self._values["project_type"] = project_type
         if readme is not None:
@@ -1503,6 +1523,65 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
         assert result is not None, "Required property 'name' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def logging(self) -> typing.Optional[_LoggerOptions_eb0f6309]:
+        '''(experimental) Configure logging options such as verbosity.
+
+        :default: {}
+
+        :stability: experimental
+        '''
+        result = self._values.get("logging")
+        return typing.cast(typing.Optional[_LoggerOptions_eb0f6309], result)
+
+    @builtins.property
+    def outdir(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The root directory of the project.
+
+        Relative to this directory, all files are synthesized.
+
+        If this project has a parent, this directory is relative to the parent
+        directory and it cannot be the same as the parent or any of it's other
+        sub-projects.
+
+        :default: "."
+
+        :stability: experimental
+        '''
+        result = self._values.get("outdir")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def parent(self) -> typing.Optional[_Project_57d89203]:
+        '''(experimental) The parent project, if this project is part of a bigger project.
+
+        :stability: experimental
+        '''
+        result = self._values.get("parent")
+        return typing.cast(typing.Optional[_Project_57d89203], result)
+
+    @builtins.property
+    def projenrc_json(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Generate (once) .projenrc.json (in JSON). Set to ``false`` in order to disable .projenrc.json generation.
+
+        :default: false
+
+        :stability: experimental
+        '''
+        result = self._values.get("projenrc_json")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def projenrc_json_options(self) -> typing.Optional[_ProjenrcOptions_985561af]:
+        '''(experimental) Options for .projenrc.json.
+
+        :default: - default options
+
+        :stability: experimental
+        '''
+        result = self._values.get("projenrc_json_options")
+        return typing.cast(typing.Optional[_ProjenrcOptions_985561af], result)
+
     @builtins.property
     def auto_approve_options(self) -> typing.Optional[_AutoApproveOptions_dac86cbe]:
         '''(experimental) Enable and configure the 'auto approve' workflow.
@@ -1585,17 +1664,6 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
         result = self._values.get("gitpod")
         return typing.cast(typing.Optional[builtins.bool], result)
 
-    @builtins.property
-    def logging(self) -> typing.Optional[_LoggerOptions_eb0f6309]:
-        '''(experimental) Configure logging options such as verbosity.
-
-        :default: {}
-
-        :stability: experimental
-        '''
-        result = self._values.get("logging")
-        return typing.cast(typing.Optional[_LoggerOptions_eb0f6309], result)
-
     @builtins.property
     def mergify(self) -> typing.Optional[builtins.bool]:
         '''(deprecated) Whether mergify should be enabled on this repository or not.
@@ -1609,40 +1677,15 @@ class JavaProjectOptions(_ProjectOptions_0d5b93c6, PomOptions):
         result = self._values.get("mergify")
         return typing.cast(typing.Optional[builtins.bool], result)
 
-    @builtins.property
-    def outdir(self) -> typing.Optional[builtins.str]:
-        '''(experimental) The root directory of the project.
-
-        Relative to this directory, all files are synthesized.
-
-        If this project has a parent, this directory is relative to the parent
-        directory and it cannot be the same as the parent or any of it's other
-        sub-projects.
-
-        :default: "."
-
-        :stability: experimental
-        '''
-        result = self._values.get("outdir")
-        return typing.cast(typing.Optional[builtins.str], result)
-
-    @builtins.property
-    def parent(self) -> typing.Optional[_Project_57d89203]:
-        '''(experimental) The parent project, if this project is part of a bigger project.
-
-        :stability: experimental
-        '''
-        result = self._values.get("parent")
-        return typing.cast(typing.Optional[_Project_57d89203], result)
-
     @builtins.property
     def project_type(self) -> typing.Optional[_ProjectType_fd80c725]:
-        '''(experimental) Which type of project this is (library/app).
+        '''(deprecated) Which type of project this is (library/app).
 
         :default: ProjectType.UNKNOWN
 
-        :stability: experimental
-        :featured: true
+        :deprecated: no longer supported at the base project level
+
+        :stability: deprecated
         '''
         result = self._values.get("project_type")
         return typing.cast(typing.Optional[_ProjectType_fd80c725], result)
