@@ -53,7 +53,7 @@ class Task(metaclass=jsii.JSIIMeta, jsii_type="projen.tasks.Task"):
             required_env=required_env,
         )
 
-        jsii.create(Task, self, [name, props])
+        jsii.create(self.__class__, self, [name, props])
 
     @jsii.member(jsii_name="builtin")
     def builtin(self, name: builtins.str) -> None:
@@ -537,7 +537,7 @@ class TaskRuntime(metaclass=jsii.JSIIMeta, jsii_type="projen.tasks.TaskRuntime")
 
         :stability: experimental
         '''
-        jsii.create(TaskRuntime, self, [workdir])
+        jsii.create(self.__class__, self, [workdir])
 
     @jsii.member(jsii_name="runTask")
     def run_task(
@@ -813,7 +813,7 @@ class Tasks(
 
         :stability: experimental
         '''
-        jsii.create(Tasks, self, [project])
+        jsii.create(self.__class__, self, [project])
 
     @jsii.member(jsii_name="addEnvironment")
     def add_environment(self, name: builtins.str, value: builtins.str) -> None:
