@@ -59,7 +59,7 @@ class DevContainer(
             vscode_extensions=vscode_extensions,
         )
 
-        jsii.create(DevContainer, self, [project, options])
+        jsii.create(self.__class__, self, [project, options])
 
     @jsii.member(jsii_name="addDockerImage")
     def add_docker_image(self, image: _DevEnvironmentDockerImage_4a8d8ffd) -> None:
@@ -370,7 +370,7 @@ class VsCode(
 
         :stability: experimental
         '''
-        jsii.create(VsCode, self, [project])
+        jsii.create(self.__class__, self, [project])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="launchConfiguration")
@@ -397,7 +397,7 @@ class VsCodeLaunchConfig(
 
         :stability: experimental
         '''
-        jsii.create(VsCodeLaunchConfig, self, [vscode])
+        jsii.create(self.__class__, self, [vscode])
 
     @jsii.member(jsii_name="addConfiguration")
     def add_configuration(
